==> openGion_dev_5.5.7.0.zip: opengion/uap/webapps/gf/src/org/opengion/hayabusa/taglib/ViewParamTag.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.taglib;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.common.HybsSystemException;

import java.util.Map;
import java.util.HashMap;
import java.io.ObjectOutputStream;
import java.io.ObjectInputStream;
import java.io.IOException;

/**
 * ViewFormTag にパラメーターを渡す為のスーパークラスです。
 *
 * ViewForm 関連の各クラスは、特殊・専用化の傾向が強くなりつつあり、
 * 設定するパラメーターも増えています。これらのパラメータを、共通の
 * ViewFormインターフェースに設定することは、得策とは考えられない為、
 * パラメーターを一括して渡すようにします。
 * ただし、key1=**** val2=**** 的な渡し方では、エラーチェックや自動ドキュメント化
 * が難しいため、各ViewFormのサブクラスごとに、パラメータクラスを作成し、
 * それらのスーパークラスとして、最終的には、同一方法で、パラメータオブジェクト
 * として渡すことにします。
 *
 * @og.rev 3.5.4.8 (2004/02/23) 新規作成
 * @og.group 画面表示
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class ViewParamTag extends CommonTagSupport {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.0.0 (2005/08/31)" ;

	private static final long serialVersionUID = 4000 ;	// 4.0.0 (2005/02/28)

	private transient Map<String,String> param = null;	// 3.5.6.2 (2004/07/05)

	/**
	 * Taglibの終了タグが見つかったときに処理する doEndTag() を オーバーライドします。
	 *
	 * @return	後続処理の指示
	 */
	@Override
	public int doEndTag() {
		debugPrint();		// 4.0.0 (2005/02/28)
		ViewFormTag viewform = (ViewFormTag)findAncestorWithClass( this,ViewFormTag.class );
		if( viewform == null ) {
			String errMsg = "<b>このタグは、ViewFormTagの内側(要素)に記述してください。</b>";
			throw new HybsSystemException( errMsg );
		}

		viewform.setParam( param );

		return(EVAL_PAGE);
	}

	/**
	 * タグリブオブジェクトをリリースします。
	 * キャッシュされて再利用されるので、フィールドの初期設定を行います。
	 *
	 */
	@Override
	protected void release2() {
		super.release2();		// 3.5.6.0 (2004/06/18) 追加(抜けていた)
		param = null;
	}

	/**
	 * パラメータのMapを初期設定します。
	 *
	 * パラメータのキーと値の初期値をセットしたMapを初期設定します。
	 * 処理のタイミングとして、すでにパラメータ変数は、設定されています。
	 * 一つも設定されていない場合は、param == null なので、引数の初期値マップを
	 * そのまま（コピーして）作成します。
	 * すでに、登録されている場合は、キーが存在しているため、キーの存在しない
	 * データのみ、初期値マップからコピーします。
	 *
	 * @og.rev 5.5.5.6 (2012/08/31) 新規追加
	 *
	 * @param   map		Map<String,String>
	 */
	protected void initParam( final Map<String,String> map ) {
		if( param == null ) {
			param = new HashMap<String,String>( map );
		}
		else {
			for ( String key : map.keySet() ) {
				if( !param.containsKey( key ) ) {	// キーが存在しなければ、初期化情報を登録する。
					param.put( key,map.get( key ) );
				}
			}
		}
	}

	/**
	 * パラメータのキーと値をセットします。
	 *
	 * パラメータのキーと値をセットします。
	 *
	 * @param   key		キー
	 * @param   value	値
	 */
	protected void putParam( final String key, final String value ) {
		if( key != null ) {
			if( param == null ) { param = new HashMap<String,String>(); }
			param.put( key,value );
		}
	}

	/**
	 * シリアライズ用のカスタムシリアライズ書き込みメソッド
	 *
	 * @og.rev 4.0.0 (2006/09/31) 新規追加
	 * @serialData
	 *
	 * @param	strm	ObjectOutputStreamオブジェクト
	 */
	private void writeObject( final ObjectOutputStream strm ) throws IOException {
		strm.defaultWriteObject();
	}

	/**
	 * シリアライズ用のカスタムシリアライズ読み込みメソッド
	 *
	 * ここでは、transient 宣言された内部変数の内、初期化が必要なフィールドのみ設定します。
	 *
	 * @og.rev 4.0.0 (2006/09/31) 新規追加
	 * @serialData
	 *
	 * @param	strm	ObjectInputStreamオブジェクト
	 * @see #release2()
	 */
	private void readObject( final ObjectInputStream strm ) throws IOException , ClassNotFoundException {
		strm.defaultReadObject();
	}

	/**
	 * このオブジェクトの文字列表現を返します。
	 * 基本的にデバッグ目的に使用します。
	 *
	 * @og.rev 5.2.1.0 (2010/10/01) Map の内容表示方法を変更
	 *
	 * @return このクラスの文字列表現
	 */
	@Override
	public String toString() {
		StringBuilder rtn = new StringBuilder( HybsSystem.BUFFER_MIDDLE );

		rtn.append( "[" ).append( this.getClass().getName() ).append( "]" ).append( HybsSystem.CR );
//		rtn.append( param     ).append( HybsSystem.CR );
		if( param != null ) {
			for ( Map.Entry<String, String> ent : param.entrySet() ) {
				rtn.append( ent.getKey() ).append( "=" ).append( ent.getValue() ).append( HybsSystem.CR );
			}
		}

		return rtn.toString();
	}
}

==> openGion_dev_5.6.6.0.zip: opengion/uap/webapps/gf/src/org/opengion/hayabusa/taglib/ViewParamTag.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.taglib;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.common.HybsSystemException;

import java.util.Map;
import java.util.HashMap;
import java.io.ObjectOutputStream;
import java.io.ObjectInputStream;
import java.io.IOException;

/**
 * ViewFormTag にパラメーターを渡す為のスーパークラスです。
 *
 * ViewForm 関連の各クラスは、特殊・専用化の傾向が強くなりつつあり、
 * 設定するパラメーターも増えています。これらのパラメータを、共通の
 * ViewFormインターフェースに設定することは、得策とは考えられない為、
 * パラメーターを一括して渡すようにします。
 * ただし、key1=**** val2=**** 的な渡し方では、エラーチェックや自動ドキュメント化
 * が難しいため、各ViewFormのサブクラスごとに、パラメータクラスを作成し、
 * それらのスーパークラスとして、最終的には、同一方法で、パラメータオブジェクト
 * として渡すことにします。
 *
 * @og.rev 3.5.4.8 (2004/02/23) 新規作成
 * @og.group 画面表示
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class ViewParamTag extends CommonTagSupport {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.5.5.6 (2012/08/31)" ;

	private static final long serialVersionUID = 555620120831L ;

	private transient Map<String,String> param = null;	// 3.5.6.2 (2004/07/05)

	/**
	 * Taglibの終了タグが見つかったときに処理する doEndTag() を オーバーライドします。
	 *
	 * @return	後続処理の指示
	 */
	@Override
	public int doEndTag() {
		debugPrint();		// 4.0.0 (2005/02/28)
		ViewFormTag viewform = (ViewFormTag)findAncestorWithClass( this,ViewFormTag.class );
		if( viewform == null ) {
			String errMsg = "<b>このタグは、ViewFormTagの内側(要素)に記述してください。</b>";
			throw new HybsSystemException( errMsg );
		}

		viewform.setParam( param );

		return(EVAL_PAGE);
	}

	/**
	 * タグリブオブジェクトをリリースします。
	 * キャッシュされて再利用されるので、フィールドの初期設定を行います。
	 *
	 */
	@Override
	protected void release2() {
		super.release2();		// 3.5.6.0 (2004/06/18) 追加(抜けていた)
		param = null;
	}

	/**
	 * パラメータのMapを初期設定します。
	 *
	 * パラメータのキーと値の初期値をセットしたMapを初期設定します。
	 * 処理のタイミングとして、すでにパラメータ変数は、設定されています。
	 * 一つも設定されていない場合は、param == null なので、引数の初期値マップを
	 * そのまま（コピーして）作成します。
	 * すでに、登録されている場合は、キーが存在しているため、キーの存在しない
	 * データのみ、初期値マップからコピーします。
	 *
	 * @og.rev 5.5.5.6 (2012/08/31) 新規追加
	 *
	 * @param   map		パラメータのMap
	 */
	protected void initParam( final Map<String,String> map ) {
		if( param == null ) {
			param = new HashMap<String,String>( map );
		}
		else {
			for ( String key : map.keySet() ) {
				if( !param.containsKey( key ) ) {	// キーが存在しなければ、初期化情報を登録する。
					param.put( key,map.get( key ) );
				}
			}
		}
	}

	/**
	 * パラメータのキーと値をセットします。
	 *
	 * パラメータのキーと値をセットします。
	 *
	 * @param   key		キー
	 * @param   value	値
	 */
	protected void putParam( final String key, final String value ) {
		if( key != null ) {
			if( param == null ) { param = new HashMap<String,String>(); }
			param.put( key,value );
		}
	}

	/**
	 * シリアライズ用のカスタムシリアライズ書き込みメソッド
	 *
	 * @og.rev 4.0.0.0 (2006/09/31) 新規追加
	 * @serialData
	 *
	 * @param	strm	ObjectOutputStreamオブジェクト
	 */
	private void writeObject( final ObjectOutputStream strm ) throws IOException {
		strm.defaultWriteObject();
	}

	/**
	 * シリアライズ用のカスタムシリアライズ読み込みメソッド
	 *
	 * ここでは、transient 宣言された内部変数の内、初期化が必要なフィールドのみ設定します。
	 *
	 * @og.rev 4.0.0.0 (2006/09/31) 新規追加
	 * @serialData
	 *
	 * @param	strm	ObjectInputStreamオブジェクト
	 * @see #release2()
	 */
	private void readObject( final ObjectInputStream strm ) throws IOException , ClassNotFoundException {
		strm.defaultReadObject();
	}

	/**
	 * このオブジェクトの文字列表現を返します。
	 * 基本的にデバッグ目的に使用します。
	 *
	 * @og.rev 5.2.1.0 (2010/10/01) Map の内容表示方法を変更
	 *
	 * @return このクラスの文字列表現
	 */
	@Override
	public String toString() {
		StringBuilder rtn = new StringBuilder( HybsSystem.BUFFER_MIDDLE );

		rtn.append( "[" ).append( this.getClass().getName() ).append( "]" ).append( HybsSystem.CR );
//		rtn.append( param     ).append( HybsSystem.CR );
		if( param != null ) {
			for ( Map.Entry<String, String> ent : param.entrySet() ) {
				rtn.append( ent.getKey() ).append( "=" ).append( ent.getValue() ).append( HybsSystem.CR );
			}
		}

		return rtn.toString();
	}
}
